#!/usr/bin/perl

# ©2019-2021 Efficient Elements GmbH. All rights reserved.

# Kill all ee4psync processes
`pkill ee4psync`;

# Remove login item
$user = getpwuid((stat($ENV{HOME}))[4]);
$cmd = "sudo -u '" . $user . "' open '/Library/Application Support/Microsoft/Office365/User Content.localized/Add-Ins.localized/Efficient Elements/Efficient Elements for presentations/Program/ee4psync.app' --args -r";
print "Removing login item: " . $cmd . "\n";
system($cmd);

# Delete install folder
`rm -rf "/Library/Application Support/Microsoft/Office365/User Content.localized/Add-Ins.localized/Efficient Elements/Efficient Elements for presentations" || true`;

sub trim { my $s = shift; $s =~ s/^\s+|\s+$//g; return $s };

# Find registry database for all users
@dirs = grep { -d } glob "/Users/* /Volumes/Preboot/Users/*";

foreach (@dirs) {
  # Delete ee4p.scpt
  $scpt = $_ . "/Library/Application Scripts/com.microsoft.Powerpoint/ee4p.scpt";
  if(-e $scpt) {
    if(unlink($scpt)) {
      print "$scpt deleted" . "\n";;
    }
    else {
      print "deleting $scpt failed: $!" . "\n";
    }
  }
  else {
    print "$scpt not found" . "\n";
  }
  
  $path = $_ . "/Library/Group Containers/UBF8T346G9.Office/MicrosoftRegistrationDB.reg";
  if (-e $path) {
    print "path: " . $path . "\n";

    # Get key 'Software'
    $software_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='Software' AND parent_id=-1;"| sqlite3 "$path"`);
    print "software_id: " . $software_id . "\n";
    if (!$software_id) {
      exit 1;
    }

    # Get key 'Software/Microsoft'
    $microsoft_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='Microsoft' AND parent_id=$software_id;"| sqlite3 "$path"`);
    print "microsoft_id: " . $microsoft_id . "\n";
    if (!$microsoft_id) {
      exit 1;
    }

    # Get key 'Software/Microsoft/Office'
    $office_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='Office' AND parent_id=$microsoft_id;"| sqlite3 "$path"`);
    print "office_id: " . $office_id . "\n";
    if (!$office_id) {
      exit 1;
    }

    # Get versions from 'Software/Microsoft/Office'
    $versions = `echo "SELECT name FROM HKEY_CURRENT_USER WHERE parent_id=$office_id AND name LIKE '__._';"| sqlite3 "$path"`;
    @versions_array = split /\n/, $versions;

    foreach $version (@versions_array) {

      print "version: " . $version . "\n";

      # Get key 'Software/Microsoft/Office/xx.x'
      $version_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='$version' AND parent_id=$office_id;"| sqlite3 "$path"`);
      print "version_id: " . $version_id . "\n";
      if (!$version_id) {
        exit 1;
      }

      # Check if key 'Software/Microsoft/Office/xx.x/PowerPoint' exists
      $powerpoint_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='PowerPoint' AND parent_id=$version_id;"| sqlite3 "$path"`);
      if ($powerpoint_id) {
        print "powerpoint_id: " . $powerpoint_id . "\n";
    
        # Check if key 'Software/Microsoft/Office/xx.x/PowerPoint/AddIns' exists
        $addins_id = trim(`echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name='AddIns' AND parent_id=$powerpoint_id;"| sqlite3 "$path"`);
        if ($addins_id) {
          print "addins_id: " . $addins_id . "\n";
      
          # Check if key 'Software/Microsoft/Office/xx.x/PowerPoint/AddIns/ee4pMacOS*' exists
          $addin_ids = `echo "SELECT node_id FROM HKEY_CURRENT_USER WHERE name LIKE 'ee4pMacOS%' AND parent_id=$addins_id;"| sqlite3 "$path"`;
          @addin_ids_array = split /\n/, $addin_ids;
          foreach $addin_id (@addin_ids_array) {
            if ($addin_id) {
              print "addin_id: " . $addin_id . "\n";
          
              `echo "DELETE FROM HKEY_CURRENT_USER WHERE node_id=$addin_id;"| sqlite3 "$path"`;
              `echo "DELETE FROM HKEY_CURRENT_USER_values WHERE node_id=$addin_id;"| sqlite3 "$path"`;
            }
          }
        }
      }
    }
  }
}

print "success" . "\n";

exit 0;
